@@ -36,6 +36,7 @@
 
 #include "gsm-util.h"
 #include "gsm-autostart-app.h"
+#include "gsm-icon-names.h"
 #include "gsm-manager.h"
 
 #define GsmDesktopFile "_GSM_DesktopFile"
@@ -505,7 +506,6 @@ get_desktop_file_path (GsmXSMPClient *client)
 {
         SmProp     *prop;
         char       *desktop_file_path = NULL;
-        char      **dirs;
         const char *program_name;
 
         /* XSMP clients using eggsmclient defines a special property
@@ -524,13 +524,9 @@ get_desktop_file_path (GsmXSMPClient *client)
         prop = find_property (client, SmProgram, NULL);
         program_name = prop->vals[0].value;
 
-        dirs = gsm_util_get_autostart_dirs ();
-
         desktop_file_path =
                 gsm_util_find_desktop_file_for_app_name (program_name,
-                                                         dirs);
-
-        g_strfreev (dirs);
+                                                         TRUE, FALSE);
 
 out:
         g_debug ("GsmXSMPClient: desktop file for client %s is %s",
@@ -567,7 +563,7 @@ set_desktop_file_keys_from_client (GsmClient *client,
         g_key_file_set_string (keyfile,
                                G_KEY_FILE_DESKTOP_GROUP,
                                G_KEY_FILE_DESKTOP_KEY_ICON,
-                               "system-run");
+                               GSM_ICON_XSMP_DEFAULT);
 
         g_key_file_set_string (keyfile,
                                G_KEY_FILE_DESKTOP_GROUP,
